==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/floppy/dialogs_fr.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Il semblerait que nous y soyons finalemnt arriver.")


dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("Penses-tu que c'est ça ?")


dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("Comment cela pourrait-il tenir sur une disquette trois pouces et demi ?")


dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Regarde, elle est bien plus grande que moi. Ce serait plutôt une disquette trente pieds et demi.")


dialogId("disk-m-velka", "font_small", "That`s better. Big plan, big disk. That makes sense.")
dialogStr("Effectivement. Gros plan, grosse disquette. Ca se tient.")


dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("Penses-tu que nous pourrons la soulever ?")


dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Ca va être difficile.")


dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("Je ne pense pas que ce soit possible. Pourquoi est-ce qu'ils l'auraient cachée ici, si nous pouvons la soulever ?")


dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("Tais-toi, ou je te casse une patte !")


dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("Peux-tu voir cette croix en acier ? C'est pour enterrer nos espoirs.")


dialogId("disk-m-depres", "font_small", "Don`t be always so gloomy. I can`t bear it.")
dialogStr("Ne sois pas toujours si lugubre. Je ne peux pas la porter.")


dialogId("disk-m-nahrat", "font_small", "Wouldn`t it be enough to download that plan from the floppy to our notebook?")
dialogStr("Ne serait-il pas suffisant de télécharger le plan depuis la disquette vers notre ordinateur portable ?")


dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Pourquoi pas, vas-y sors le.")


dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("Oh, zut. Je l'ai laissé à la maison.")


dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("Est-ce que nous allons le chercher ?")


dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Jamais. C'est peut-être marrant pour toi, mais moi j'ai les nageoires endolories.")


dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Réfléchis un peu. Je suis curieux de voir comment tu vas le faire.")


dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("Et s'il n'y avait aucun plan sur la disquette ? Et si c'était juste pour nous tromper ?")


dialogId("disk-v-neverim", "font_big", "I don`t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("Je ne crois pas. Est-ce qu'il y a ici un objet plus difficile à emporter ?")


dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("Quelle sorte de petites créatures est-ce ?")


dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("Ceux sont des virus informatiques.")


dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Argh. Des monstres.")


dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn`t be happy if we pour them on their desktop.")
dialogStr("Après tout, nous devons prendre gare à ne pas les emporter avec la disquette. Le joueur(euse) ne serait pas content(e) si nous les déversons sur son bureau.")


dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Notre but est de faire sortir la disquette.")


dialogId("disk-x-nepohnes", "font_darkgrey", "You won`t move me easily!")
dialogStr("Vous ne me bougerez pas facilement !")


dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("Plutôt malin !")


dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Oups!")


dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("Malheur !")


dialogId("disk-x-au2", "font_darkgrey", "Yup.")
dialogStr("Aïe.")


dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("Laisser moi tranquille !")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/floppy/dialogs_fr.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Il semblerait que nous y soyons finalement arrivés.")


dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("Penses-tu que c'est ça ?")


dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("Comment cela pouvait-il tenir sur une disquette trois pouces et demi ?")


dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Regarde, elle est bien plus grande que moi. Ce serait plutôt une disquette trois mètres et demi.")


dialogId("disk-m-velka", "font_small", "That’s better. Big plan, big disk. That makes sense.")
dialogStr("Effectivement. Gros plan, grosse disquette. Ça se tient.")


dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("Penses-tu que nous pourrons la soulever ?")


dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Ca va être difficile.")


dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("Je ne pense pas que ce soit possible. Pourquoi est-ce qu'ils l'auraient cachée ici, si nous pouvons la soulever ?")


dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("Tais-toi, ou je te casse une patte !")


dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("Tu vois cette croix en acier ? C'est pour enterrer nos espoirs.")


dialogId("disk-m-depres", "font_small", "Don’t be always so gloomy. I can’t bear it.")
dialogStr("Ne sois pas toujours si lugubre. Je ne peux pas le supporter.")


dialogId("disk-m-nahrat", "font_small", "Wouldn’t it be enough to download that plan from the floppy to our notebook?")
dialogStr("Ne serait-il pas suffisant de télécharger le plan depuis la disquette vers notre ordinateur portable ?")


dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Pourquoi pas, vas-y sors le.")


dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("Oh, zut! Je l'ai laissé à la maison.")


dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("Est-ce que nous allons le chercher ?")


dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Jamais. C'est peut-être marrant pour toi, mais moi j'ai les nageoires endolories.")


dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Comme tu veux. Je suis curieux de voir comment tu vas le faire.")


dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("Et s'il n'y avait aucun plan sur la disquette ? Et si c'était juste pour nous tromper ?")


dialogId("disk-v-neverim", "font_big", "I don’t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("Je ne crois pas. Est-ce qu'il y a ici un objet plus difficile à emporter ?")


dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("Quelle sorte de petites créatures est-ce ?")


dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("Ce sont sans doute des virus informatiques.")


dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Argh. Des monstres.")


dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn’t be happy if we pour them on their desktop.")
dialogStr("Avant tout, nous devons prendre gare à ne pas les emporter avec la disquette. Le joueur(euse) ne serait pas content(e) si nous les déversons sur son bureau.")


dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Notre but est de faire sortir la disquette.")


dialogId("disk-x-nepohnes", "font_darkgrey", "You won’t move me easily!")
dialogStr("Vous ne me bougerez pas facilement !")


dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("Plutôt malin !")


dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Oups!")


dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("Malheur !")


dialogId("disk-x-au2", "font_darkgrey", "Yup.")
dialogStr("Aïe.")


dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("Laissez-moi tranquille !")
